@@ -1,13 +1,13 @@
 from slither.core.source_mapping.source_mapping import SourceMapping
 
-class Import(SourceMapping):
 
-    def __init__(self, filename):
-        super(Import, self).__init__()
+class Import(SourceMapping):
+    def __init__(self, filename: str):
+        super().__init__()
         self._filename = filename
 
     @property
-    def filename(self):
+    def filename(self) -> str:
         return self._filename
 
     def __str__(self):
