@@ -6,17 +6,16 @@ class Backdoor(AbstractDetector):
     Detect function named backdoor
     """
 
-    ARGUMENT = 'backdoor'  # slither will launch the detector with slither.py --mydetector
-    HELP = 'Function named backdoor (detector example)'
+    ARGUMENT = "backdoor"  # slither will launch the detector with slither.py --mydetector
+    HELP = "Function named backdoor (detector example)"
     IMPACT = DetectorClassification.HIGH
     CONFIDENCE = DetectorClassification.HIGH
 
-
-    WIKI = 'https://github.com/trailofbits/slither/wiki/Adding-a-new-detector'
-    WIKI_TITLE = 'Backdoor example'
-    WIKI_DESCRIPTION = 'Plugin example'
-    WIKI_EXPLOIT_SCENARIO = '..'
-    WIKI_RECOMMENDATION = '..'
+    WIKI = "https://github.com/trailofbits/slither/wiki/Adding-a-new-detector"
+    WIKI_TITLE = "Backdoor example"
+    WIKI_DESCRIPTION = "Plugin example"
+    WIKI_EXPLOIT_SCENARIO = ".."
+    WIKI_RECOMMENDATION = ".."
 
     def _detect(self):
         results = []
@@ -24,9 +23,9 @@ class Backdoor(AbstractDetector):
         for contract in self.slither.contracts_derived:
             # Check if a function has 'backdoor' in its name
             for f in contract.functions:
-                if 'backdoor' in f.name:
+                if "backdoor" in f.name:
                     # Info to be printed
-                    info = ['Backdoor function found in ', f, '\n']
+                    info = ["Backdoor function found in ", f, "\n"]
 
                     # Add the result in result
                     res = self.generate_result(info)
