@@ -4,13 +4,13 @@ from slither.slithir.utils.utils import is_valid_lvalue, is_valid_rvalue
 
 
 class Length(OperationWithLValue):
-
     def __init__(self, value, lvalue):
+        super().__init__()
         assert is_valid_rvalue(value)
         assert is_valid_lvalue(lvalue)
         self._value = value
         self._lvalue = lvalue
-        lvalue.set_type(ElementaryType('uint256'))
+        lvalue.set_type(ElementaryType("uint256"))
 
     @property
     def read(self):
