@@ -1,10 +1,10 @@
 from slither.slithir.operations.lvalue import OperationWithLValue
 from slither.core.solidity_types.type import Type
 
-class TmpNewArray(OperationWithLValue):
 
+class TmpNewArray(OperationWithLValue):
     def __init__(self, depth, array_type, lvalue):
-        super(TmpNewArray, self).__init__()
+        super().__init__()
         assert isinstance(array_type, Type)
         self._depth = depth
         self._array_type = array_type
@@ -23,5 +23,4 @@ class TmpNewArray(OperationWithLValue):
         return self._depth
 
     def __str__(self):
-        return '{} = new {}{}'.format(self.lvalue, self.array_type, '[]'*self._depth)
-
+        return "{} = new {}{}".format(self.lvalue, self.array_type, "[]" * self._depth)
