@@ -1,11 +1,11 @@
 from slither.slithir.operations.lvalue import OperationWithLValue
 from slither.core.solidity_types.elementary_type import ElementaryType
 
-class TmpNewElementaryType(OperationWithLValue):
 
+class TmpNewElementaryType(OperationWithLValue):
     def __init__(self, new_type, lvalue):
         assert isinstance(new_type, ElementaryType)
-        super(TmpNewElementaryType, self).__init__()
+        super().__init__()
         self._type = new_type
         self._lvalue = lvalue
 
@@ -18,4 +18,4 @@ class TmpNewElementaryType(OperationWithLValue):
         return self._type
 
     def __str__(self):
-        return '{} = new {}'.format(self.lvalue, self._type)
+        return "{} = new {}".format(self.lvalue, self._type)
