@@ -4,7 +4,7 @@ import json
 import logging
 import zipfile
 from collections import OrderedDict
-from typing import Optional, Dict
+from typing import Optional, Dict, List, Union, Any
 from zipfile import ZipFile
 
 from slither.core.cfg.node import Node
@@ -25,7 +25,7 @@ logger = logging.getLogger("Slither")
 ###################################################################################
 
 
-def output_to_json(filename, error, results):
+def output_to_json(filename: str, error, results: Dict):
     """
 
     :param filename: Filename where the json will be written. If None or "-", write to stdout
@@ -35,11 +35,7 @@ def output_to_json(filename, error, results):
     :return:
     """
     # Create our encapsulated JSON result.
-    json_result = {
-        "success": error is None,
-        "error": error,
-        "results": results
-    }
+    json_result = {"success": error is None, "error": error, "results": results}
 
     if filename == "-":
         filename = None
@@ -51,17 +47,19 @@ def output_to_json(filename, error, results):
     else:
         # Write json to file
         if os.path.isfile(filename):
-            logger.info(yellow(f'{filename} exists already, the overwrite is prevented'))
+            logger.info(yellow(f"{filename} exists already, the overwrite is prevented"))
         else:
-            with open(filename, 'w', encoding='utf8') as f:
+            with open(filename, "w", encoding="utf8") as f:
                 json.dump(json_result, f, indent=2)
 
 
 # https://docs.python.org/3/library/zipfile.html#zipfile-objects
-ZIP_TYPES_ACCEPTED = {'lzma': zipfile.ZIP_LZMA,
-                      'stored': zipfile.ZIP_STORED,
-                      'deflated': zipfile.ZIP_DEFLATED,
-                      'bzip2': zipfile.ZIP_BZIP2}
+ZIP_TYPES_ACCEPTED = {
+    "lzma": zipfile.ZIP_LZMA,
+    "stored": zipfile.ZIP_STORED,
+    "deflated": zipfile.ZIP_DEFLATED,
+    "bzip2": zipfile.ZIP_BZIP2,
+}
 
 
 def output_to_zip(filename: str, error: Optional[str], results: Dict, zip_type: str = "lzma"):
@@ -75,16 +73,16 @@ def output_to_zip(filename: str, error: Optional[str], results: Dict, zip_type:
     :param results:
     :return:
     """
-    json_result = {
-        "success": error is None,
-        "error": error,
-        "results": results
-    }
+    json_result = {"success": error is None, "error": error, "results": results}
     if os.path.isfile(filename):
-        logger.info(yellow(f'{filename} exists already, the overwrite is prevented'))
+        logger.info(yellow(f"{filename} exists already, the overwrite is prevented"))
     else:
-        with ZipFile(filename, "w", compression=ZIP_TYPES_ACCEPTED.get(zip_type, zipfile.ZIP_LZMA)) as file_desc:
-            file_desc.writestr("slither_results.json", json.dumps(json_result).encode('utf8'))
+        with ZipFile(
+            filename,
+            "w",
+            compression=ZIP_TYPES_ACCEPTED.get(zip_type, zipfile.ZIP_LZMA),
+        ) as file_desc:
+            file_desc.writestr("slither_results.json", json.dumps(json_result).encode("utf8"))
 
 
 # endregion
@@ -94,26 +92,26 @@ def output_to_zip(filename: str, error: Optional[str], results: Dict, zip_type:
 ###################################################################################
 ###################################################################################
 
+
 def _convert_to_description(d):
     if isinstance(d, str):
         return d
 
     if not isinstance(d, SourceMapping):
-        raise SlitherError(f'{d} does not inherit from SourceMapping, conversion impossible')
+        raise SlitherError(f"{d} does not inherit from SourceMapping, conversion impossible")
 
     if isinstance(d, Node):
         if d.expression:
-            return f'{d.expression} ({d.source_mapping_str})'
-        else:
-            return f'{str(d)} ({d.source_mapping_str})'
+            return f"{d.expression} ({d.source_mapping_str})"
+        return f"{str(d)} ({d.source_mapping_str})"
 
-    if hasattr(d, 'canonical_name'):
-        return f'{d.canonical_name} ({d.source_mapping_str})'
+    if hasattr(d, "canonical_name"):
+        return f"{d.canonical_name} ({d.source_mapping_str})"
 
-    if hasattr(d, 'name'):
-        return f'{d.name} ({d.source_mapping_str})'
+    if hasattr(d, "name"):
+        return f"{d.name} ({d.source_mapping_str})"
 
-    raise SlitherError(f'{type(d)} cannot be converted (no name, or canonical_name')
+    raise SlitherError(f"{type(d)} cannot be converted (no name, or canonical_name")
 
 
 def _convert_to_markdown(d, markdown_root):
@@ -121,51 +119,49 @@ def _convert_to_markdown(d, markdown_root):
         return d
 
     if not isinstance(d, SourceMapping):
-        raise SlitherError(f'{d} does not inherit from SourceMapping, conversion impossible')
+        raise SlitherError(f"{d} does not inherit from SourceMapping, conversion impossible")
 
     if isinstance(d, Node):
         if d.expression:
-            return f'[{d.expression}]({d.source_mapping_to_markdown(markdown_root)})'
-        else:
-            return f'[{str(d)}]({d.source_mapping_to_markdown(markdown_root)})'
+            return f"[{d.expression}]({d.source_mapping_to_markdown(markdown_root)})"
+        return f"[{str(d)}]({d.source_mapping_to_markdown(markdown_root)})"
 
-    if hasattr(d, 'canonical_name'):
-        return f'[{d.canonical_name}]({d.source_mapping_to_markdown(markdown_root)})'
+    if hasattr(d, "canonical_name"):
+        return f"[{d.canonical_name}]({d.source_mapping_to_markdown(markdown_root)})"
 
-    if hasattr(d, 'name'):
-        return f'[{d.name}]({d.source_mapping_to_markdown(markdown_root)})'
+    if hasattr(d, "name"):
+        return f"[{d.name}]({d.source_mapping_to_markdown(markdown_root)})"
 
-    raise SlitherError(f'{type(d)} cannot be converted (no name, or canonical_name')
+    raise SlitherError(f"{type(d)} cannot be converted (no name, or canonical_name")
 
 
 def _convert_to_id(d):
-    '''
+    """
     Id keeps the source mapping of the node, otherwise we risk to consider two different node as the same
     :param d:
     :return:
-    '''
+    """
     if isinstance(d, str):
         return d
 
     if not isinstance(d, SourceMapping):
-        raise SlitherError(f'{d} does not inherit from SourceMapping, conversion impossible')
+        raise SlitherError(f"{d} does not inherit from SourceMapping, conversion impossible")
 
     if isinstance(d, Node):
         if d.expression:
-            return f'{d.expression} ({d.source_mapping_str})'
-        else:
-            return f'{str(d)} ({d.source_mapping_str})'
+            return f"{d.expression} ({d.source_mapping_str})"
+        return f"{str(d)} ({d.source_mapping_str})"
 
     if isinstance(d, Pragma):
-        return f'{d} ({d.source_mapping_str})'
+        return f"{d} ({d.source_mapping_str})"
 
-    if hasattr(d, 'canonical_name'):
-        return f'{d.canonical_name}'
+    if hasattr(d, "canonical_name"):
+        return f"{d.canonical_name}"
 
-    if hasattr(d, 'name'):
-        return f'{d.name}'
+    if hasattr(d, "name"):
+        return f"{d.name}"
 
-    raise SlitherError(f'{type(d)} cannot be converted (no name, or canonical_name')
+    raise SlitherError(f"{type(d)} cannot be converted (no name, or canonical_name")
 
 
 # endregion
@@ -175,60 +171,74 @@ def _convert_to_id(d):
 ###################################################################################
 ###################################################################################
 
-def _create_base_element(type, name, source_mapping, type_specific_fields=None, additional_fields=None):
+
+def _create_base_element(
+    custom_type, name, source_mapping, type_specific_fields=None, additional_fields=None
+):
     if additional_fields is None:
         additional_fields = {}
     if type_specific_fields is None:
         type_specific_fields = {}
-    element = {'type': type,
-               'name': name,
-               'source_mapping': source_mapping}
+    element = {"type": custom_type, "name": name, "source_mapping": source_mapping}
     if type_specific_fields:
-        element['type_specific_fields'] = type_specific_fields
+        element["type_specific_fields"] = type_specific_fields
     if additional_fields:
-        element['additional_fields'] = additional_fields
+        element["additional_fields"] = additional_fields
     return element
 
 
 def _create_parent_element(element):
+    # pylint: disable=import-outside-toplevel
     from slither.core.children.child_contract import ChildContract
     from slither.core.children.child_function import ChildFunction
     from slither.core.children.child_inheritance import ChildInheritance
+
     if isinstance(element, ChildInheritance):
         if element.contract_declarer:
-            contract = Output('')
+            contract = Output("")
             contract.add_contract(element.contract_declarer)
-            return contract.data['elements'][0]
+            return contract.data["elements"][0]
     elif isinstance(element, ChildContract):
         if element.contract:
-            contract = Output('')
+            contract = Output("")
             contract.add_contract(element.contract)
-            return contract.data['elements'][0]
+            return contract.data["elements"][0]
     elif isinstance(element, ChildFunction):
         if element.function:
-            function = Output('')
+            function = Output("")
             function.add_function(element.function)
-            return function.data['elements'][0]
+            return function.data["elements"][0]
     return None
 
 
-class Output:
+SupportedOutput = Union[Variable, Contract, Function, Enum, Event, Structure, Pragma, Node]
 
-    def __init__(self, info, additional_fields=None, markdown_root='', standard_format=True):
+
+class Output:
+    def __init__(
+        self,
+        info_: Union[str, List[Union[str, SupportedOutput]]],
+        additional_fields: Optional[Dict] = None,
+        markdown_root="",
+        standard_format=True,
+    ):
         if additional_fields is None:
             additional_fields = {}
 
         # Allow info to be a string to simplify the API
-        if isinstance(info, str):
-            info = [info]
+        info: List[Union[str, SupportedOutput]]
+        if isinstance(info_, str):
+            info = [info_]
+        else:
+            info = info_
 
-        self._data = OrderedDict()
-        self._data['elements'] = []
-        self._data['description'] = ''.join(_convert_to_description(d) for d in info)
-        self._data['markdown'] = ''.join(_convert_to_markdown(d, markdown_root) for d in info)
+        self._data: Dict[str, Any] = OrderedDict()
+        self._data["elements"] = []
+        self._data["description"] = "".join(_convert_to_description(d) for d in info)
+        self._data["markdown"] = "".join(_convert_to_markdown(d, markdown_root) for d in info)
 
-        id_txt = ''.join(_convert_to_id(d) for d in info)
-        self._data['id'] = hashlib.sha3_256(id_txt.encode('utf-8')).hexdigest()
+        id_txt = "".join(_convert_to_id(d) for d in info)
+        self._data["id"] = hashlib.sha3_256(id_txt.encode("utf-8")).hexdigest()
 
         if standard_format:
             to_add = [i for i in info if not isinstance(i, str)]
@@ -237,9 +247,9 @@ class Output:
                 self.add(add)
 
         if additional_fields:
-            self._data['additional_fields'] = additional_fields
+            self._data["additional_fields"] = additional_fields
 
-    def add(self, add, additional_fields=None):
+    def add(self, add: SupportedOutput, additional_fields: Optional[Dict] = None):
         if isinstance(add, Variable):
             self.add_variable(add, additional_fields=additional_fields)
         elif isinstance(add, Contract):
@@ -257,15 +267,15 @@ class Output:
         elif isinstance(add, Node):
             self.add_node(add, additional_fields=additional_fields)
         else:
-            raise SlitherError(f'Impossible to add {type(add)} to the json')
+            raise SlitherError(f"Impossible to add {type(add)} to the json")
 
     @property
-    def data(self):
+    def data(self) -> Dict:
         return self._data
 
     @property
-    def elements(self):
-        return self._data['elements']
+    def elements(self) -> List[Dict]:
+        return self._data["elements"]
 
     # endregion
     ###################################################################################
@@ -274,20 +284,20 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_variable(self, variable, additional_fields=None):
+    def add_variable(self, variable: Variable, additional_fields: Optional[Dict] = None):
         if additional_fields is None:
             additional_fields = {}
-        type_specific_fields = {
-            'parent': _create_parent_element(variable)
-        }
-        element = _create_base_element('variable',
-                                       variable.name,
-                                       variable.source_mapping,
-                                       type_specific_fields,
-                                       additional_fields)
-        self._data['elements'].append(element)
+        type_specific_fields = {"parent": _create_parent_element(variable)}
+        element = _create_base_element(
+            "variable",
+            variable.name,
+            variable.source_mapping,
+            type_specific_fields,
+            additional_fields,
+        )
+        self._data["elements"].append(element)
 
-    def add_variables(self, variables):
+    def add_variables(self, variables: List[Variable]):
         for variable in sorted(variables, key=lambda x: x.name):
             self.add_variable(variable)
 
@@ -298,15 +308,13 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_contract(self, contract, additional_fields=None):
+    def add_contract(self, contract: Contract, additional_fields: Optional[Dict] = None):
         if additional_fields is None:
             additional_fields = {}
-        element = _create_base_element('contract',
-                                       contract.name,
-                                       contract.source_mapping,
-                                       {},
-                                       additional_fields)
-        self._data['elements'].append(element)
+        element = _create_base_element(
+            "contract", contract.name, contract.source_mapping, {}, additional_fields
+        )
+        self._data["elements"].append(element)
 
     # endregion
     ###################################################################################
@@ -315,21 +323,23 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_function(self, function, additional_fields=None):
+    def add_function(self, function: Function, additional_fields: Optional[Dict] = None):
         if additional_fields is None:
             additional_fields = {}
         type_specific_fields = {
-            'parent': _create_parent_element(function),
-            'signature': function.full_name
+            "parent": _create_parent_element(function),
+            "signature": function.full_name,
         }
-        element = _create_base_element('function',
-                                       function.name,
-                                       function.source_mapping,
-                                       type_specific_fields,
-                                       additional_fields)
-        self._data['elements'].append(element)
+        element = _create_base_element(
+            "function",
+            function.name,
+            function.source_mapping,
+            type_specific_fields,
+            additional_fields,
+        )
+        self._data["elements"].append(element)
 
-    def add_functions(self, functions, additional_fields=None):
+    def add_functions(self, functions: List[Function], additional_fields: Optional[Dict] = None):
         if additional_fields is None:
             additional_fields = {}
         for function in sorted(functions, key=lambda x: x.name):
@@ -342,18 +352,18 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_enum(self, enum, additional_fields=None):
+    def add_enum(self, enum: Enum, additional_fields: Optional[Dict] = None):
         if additional_fields is None:
             additional_fields = {}
-        type_specific_fields = {
-            'parent': _create_parent_element(enum)
-        }
-        element = _create_base_element('enum',
-                                       enum.name,
-                                       enum.source_mapping,
-                                       type_specific_fields,
-                                       additional_fields)
-        self._data['elements'].append(element)
+        type_specific_fields = {"parent": _create_parent_element(enum)}
+        element = _create_base_element(
+            "enum",
+            enum.name,
+            enum.source_mapping,
+            type_specific_fields,
+            additional_fields,
+        )
+        self._data["elements"].append(element)
 
     # endregion
     ###################################################################################
@@ -362,18 +372,18 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_struct(self, struct, additional_fields=None):
+    def add_struct(self, struct: Structure, additional_fields: Optional[Dict] = None):
         if additional_fields is None:
             additional_fields = {}
-        type_specific_fields = {
-            'parent': _create_parent_element(struct)
-        }
-        element = _create_base_element('struct',
-                                       struct.name,
-                                       struct.source_mapping,
-                                       type_specific_fields,
-                                       additional_fields)
-        self._data['elements'].append(element)
+        type_specific_fields = {"parent": _create_parent_element(struct)}
+        element = _create_base_element(
+            "struct",
+            struct.name,
+            struct.source_mapping,
+            type_specific_fields,
+            additional_fields,
+        )
+        self._data["elements"].append(element)
 
     # endregion
     ###################################################################################
@@ -382,20 +392,22 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_event(self, event, additional_fields=None):
+    def add_event(self, event: Event, additional_fields: Optional[Dict] = None):
         if additional_fields is None:
             additional_fields = {}
         type_specific_fields = {
-            'parent': _create_parent_element(event),
-            'signature': event.full_name
+            "parent": _create_parent_element(event),
+            "signature": event.full_name,
         }
-        element = _create_base_element('event',
-                                       event.name,
-                                       event.source_mapping,
-                                       type_specific_fields,
-                                       additional_fields)
+        element = _create_base_element(
+            "event",
+            event.name,
+            event.source_mapping,
+            type_specific_fields,
+            additional_fields,
+        )
 
-        self._data['elements'].append(element)
+        self._data["elements"].append(element)
 
     # endregion
     ###################################################################################
@@ -404,21 +416,23 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_node(self, node, additional_fields=None):
+    def add_node(self, node: Node, additional_fields: Optional[Dict] = None):
         if additional_fields is None:
             additional_fields = {}
         type_specific_fields = {
-            'parent': _create_parent_element(node),
+            "parent": _create_parent_element(node),
         }
         node_name = str(node.expression) if node.expression else ""
-        element = _create_base_element('node',
-                                       node_name,
-                                       node.source_mapping,
-                                       type_specific_fields,
-                                       additional_fields)
-        self._data['elements'].append(element)
+        element = _create_base_element(
+            "node",
+            node_name,
+            node.source_mapping,
+            type_specific_fields,
+            additional_fields,
+        )
+        self._data["elements"].append(element)
 
-    def add_nodes(self, nodes):
+    def add_nodes(self, nodes: List[Node]):
         for node in sorted(nodes, key=lambda x: x.node_id):
             self.add_node(node)
 
@@ -429,18 +443,18 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_pragma(self, pragma, additional_fields=None):
+    def add_pragma(self, pragma: Pragma, additional_fields: Optional[Dict] = None):
         if additional_fields is None:
             additional_fields = {}
-        type_specific_fields = {
-            'directive': pragma.directive
-        }
-        element = _create_base_element('pragma',
-                                       pragma.version,
-                                       pragma.source_mapping,
-                                       type_specific_fields,
-                                       additional_fields)
-        self._data['elements'].append(element)
+        type_specific_fields = {"directive": pragma.directive}
+        element = _create_base_element(
+            "pragma",
+            pragma.version,
+            pragma.source_mapping,
+            type_specific_fields,
+            additional_fields,
+        )
+        self._data["elements"].append(element)
 
     # endregion
     ###################################################################################
@@ -449,18 +463,13 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_file(self, filename, content, additional_fields=None):
+    def add_file(self, filename: str, content: str, additional_fields: Optional[Dict] = None):
         if additional_fields is None:
             additional_fields = {}
-        type_specific_fields = {
-            'filename': filename,
-            'content': content
-        }
-        element = _create_base_element('file',
-                                       type_specific_fields,
-                                       additional_fields)
+        type_specific_fields = {"filename": filename, "content": content}
+        element = _create_base_element("file", type_specific_fields, additional_fields)
 
-        self._data['elements'].append(element)
+        self._data["elements"].append(element)
 
     # endregion
     ###################################################################################
@@ -469,18 +478,18 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_pretty_table(self, content: MyPrettyTable, name, additional_fields=None):
+    def add_pretty_table(
+        self,
+        content: MyPrettyTable,
+        name: str,
+        additional_fields: Optional[Dict] = None,
+    ):
         if additional_fields is None:
             additional_fields = {}
-        type_specific_fields = {
-            'content': content.to_json(),
-            'name': name
-        }
-        element = _create_base_element('pretty_table',
-                                       type_specific_fields,
-                                       additional_fields)
+        type_specific_fields = {"content": content.to_json(), "name": name}
+        element = _create_base_element("pretty_table", type_specific_fields, additional_fields)
 
-        self._data['elements'].append(element)
+        self._data["elements"].append(element)
 
     # endregion
     ###################################################################################
@@ -489,7 +498,13 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_other(self, name, source_mapping, slither, additional_fields=None):
+    def add_other(
+        self,
+        name: str,
+        source_mapping,
+        slither,
+        additional_fields: Optional[Dict] = None,
+    ):
         # If this a tuple with (filename, start, end), convert it to a source mapping.
         if additional_fields is None:
             additional_fields = {}
@@ -497,8 +512,16 @@ class Output:
             # Parse the source id
             (filename, start, end) = source_mapping
             source_id = next(
-                (source_unit_id for (source_unit_id, source_unit_filename) in slither.source_units.items() if
-                 source_unit_filename == filename), -1)
+                (
+                    source_unit_id
+                    for (
+                        source_unit_id,
+                        source_unit_filename,
+                    ) in slither.source_units.items()
+                    if source_unit_filename == filename
+                ),
+                -1,
+            )
 
             # Convert to a source mapping string
             source_mapping = f"{start}:{end}:{source_id}"
@@ -514,9 +537,5 @@ class Output:
             source_mapping = source_mapping.source_mapping
 
         # Create the underlying element and add it to our resulting json
-        element = _create_base_element('other',
-                                       name,
-                                       source_mapping,
-                                       {},
-                                       additional_fields)
-        self._data['elements'].append(element)
+        element = _create_base_element("other", name, source_mapping, {}, additional_fields)
+        self._data["elements"].append(element)
