@@ -1,27 +1,50 @@
 import logging
 
-from slither.core.declarations import Function
-from slither.core.expressions import (AssignmentOperationType,
-                                      UnaryOperationType)
-from slither.slithir.operations import (Assignment, Binary, BinaryType, Delete,
-                                        Index, InitArray, InternalCall, Member,
-                                        NewArray, NewContract,
-                                        TypeConversion, Unary, Unpack, Return)
+from slither.core.declarations import (
+    Function,
+    SolidityVariable,
+    SolidityVariableComposed,
+)
+from slither.core.expressions import (
+    AssignmentOperationType,
+    UnaryOperationType,
+    BinaryOperationType,
+)
+from slither.core.solidity_types import ArrayType, ElementaryType
+from slither.core.solidity_types.type import Type
+from slither.core.variables.local_variable_init_from_tuple import LocalVariableInitFromTuple
+from slither.slithir.exceptions import SlithIRError
+from slither.slithir.operations import (
+    Assignment,
+    Binary,
+    BinaryType,
+    Delete,
+    Index,
+    InitArray,
+    InternalCall,
+    Member,
+    TypeConversion,
+    Unary,
+    Unpack,
+    Return,
+)
 from slither.slithir.tmp_operations.argument import Argument
 from slither.slithir.tmp_operations.tmp_call import TmpCall
 from slither.slithir.tmp_operations.tmp_new_array import TmpNewArray
 from slither.slithir.tmp_operations.tmp_new_contract import TmpNewContract
-from slither.slithir.tmp_operations.tmp_new_elementary_type import \
-    TmpNewElementaryType
-from slither.slithir.variables import (Constant, ReferenceVariable,
-                                       TemporaryVariable, TupleVariable)
+from slither.slithir.tmp_operations.tmp_new_elementary_type import TmpNewElementaryType
+from slither.slithir.variables import (
+    Constant,
+    ReferenceVariable,
+    TemporaryVariable,
+    TupleVariable,
+)
 from slither.visitors.expression.expression import ExpressionVisitor
 
-from slither.slithir.exceptions import SlithIRError
-
 logger = logging.getLogger("VISTIOR:ExpressionToSlithIR")
 
-key = 'expressionToSlithIR'
+key = "expressionToSlithIR"
+
 
 def get(expression):
     val = expression.context[key]
@@ -29,39 +52,73 @@ def get(expression):
     del expression.context[key]
     return val
 
+
 def set_val(expression, val):
     expression.context[key] = val
 
+
+_binary_to_binary = {
+    BinaryOperationType.POWER: BinaryType.POWER,
+    BinaryOperationType.MULTIPLICATION: BinaryType.MULTIPLICATION,
+    BinaryOperationType.DIVISION: BinaryType.DIVISION,
+    BinaryOperationType.MODULO: BinaryType.MODULO,
+    BinaryOperationType.ADDITION: BinaryType.ADDITION,
+    BinaryOperationType.SUBTRACTION: BinaryType.SUBTRACTION,
+    BinaryOperationType.LEFT_SHIFT: BinaryType.LEFT_SHIFT,
+    BinaryOperationType.RIGHT_SHIFT: BinaryType.RIGHT_SHIFT,
+    BinaryOperationType.AND: BinaryType.AND,
+    BinaryOperationType.CARET: BinaryType.CARET,
+    BinaryOperationType.OR: BinaryType.OR,
+    BinaryOperationType.LESS: BinaryType.LESS,
+    BinaryOperationType.GREATER: BinaryType.GREATER,
+    BinaryOperationType.LESS_EQUAL: BinaryType.LESS_EQUAL,
+    BinaryOperationType.GREATER_EQUAL: BinaryType.GREATER_EQUAL,
+    BinaryOperationType.EQUAL: BinaryType.EQUAL,
+    BinaryOperationType.NOT_EQUAL: BinaryType.NOT_EQUAL,
+    BinaryOperationType.ANDAND: BinaryType.ANDAND,
+    BinaryOperationType.OROR: BinaryType.OROR,
+}
+
+_signed_to_unsigned = {
+    BinaryOperationType.DIVISION_SIGNED: BinaryType.DIVISION,
+    BinaryOperationType.MODULO_SIGNED: BinaryType.MODULO,
+    BinaryOperationType.LESS_SIGNED: BinaryType.LESS,
+    BinaryOperationType.GREATER_SIGNED: BinaryType.GREATER,
+    BinaryOperationType.RIGHT_SHIFT_ARITHMETIC: BinaryType.RIGHT_SHIFT,
+}
+
+
 def convert_assignment(left, right, t, return_type):
     if t == AssignmentOperationType.ASSIGN:
         return Assignment(left, right, return_type)
-    elif t == AssignmentOperationType.ASSIGN_OR:
+    if t == AssignmentOperationType.ASSIGN_OR:
         return Binary(left, left, right, BinaryType.OR)
-    elif t == AssignmentOperationType.ASSIGN_CARET:
+    if t == AssignmentOperationType.ASSIGN_CARET:
         return Binary(left, left, right, BinaryType.CARET)
-    elif t == AssignmentOperationType.ASSIGN_AND:
+    if t == AssignmentOperationType.ASSIGN_AND:
         return Binary(left, left, right, BinaryType.AND)
-    elif t == AssignmentOperationType.ASSIGN_LEFT_SHIFT:
+    if t == AssignmentOperationType.ASSIGN_LEFT_SHIFT:
         return Binary(left, left, right, BinaryType.LEFT_SHIFT)
-    elif t == AssignmentOperationType.ASSIGN_RIGHT_SHIFT:
+    if t == AssignmentOperationType.ASSIGN_RIGHT_SHIFT:
         return Binary(left, left, right, BinaryType.RIGHT_SHIFT)
-    elif t == AssignmentOperationType.ASSIGN_ADDITION:
+    if t == AssignmentOperationType.ASSIGN_ADDITION:
         return Binary(left, left, right, BinaryType.ADDITION)
-    elif t == AssignmentOperationType.ASSIGN_SUBTRACTION:
+    if t == AssignmentOperationType.ASSIGN_SUBTRACTION:
         return Binary(left, left, right, BinaryType.SUBTRACTION)
-    elif t == AssignmentOperationType.ASSIGN_MULTIPLICATION:
+    if t == AssignmentOperationType.ASSIGN_MULTIPLICATION:
         return Binary(left, left, right, BinaryType.MULTIPLICATION)
-    elif t == AssignmentOperationType.ASSIGN_DIVISION:
+    if t == AssignmentOperationType.ASSIGN_DIVISION:
         return Binary(left, left, right, BinaryType.DIVISION)
-    elif t == AssignmentOperationType.ASSIGN_MODULO:
+    if t == AssignmentOperationType.ASSIGN_MODULO:
         return Binary(left, left, right, BinaryType.MODULO)
 
-    raise SlithIRError('Missing type during assignment conversion')
+    raise SlithIRError("Missing type during assignment conversion")
+
 
 class ExpressionToSlithIR(ExpressionVisitor):
+    def __init__(self, expression, node):  # pylint: disable=super-init-not-called
+        from slither.core.cfg.node import NodeType  # pylint: disable=import-outside-toplevel
 
-    def __init__(self, expression, node):
-        from slither.core.cfg.node import NodeType
         self._expression = expression
         self._node = node
         self._result = []
@@ -79,23 +136,47 @@ class ExpressionToSlithIR(ExpressionVisitor):
     def _post_assignement_operation(self, expression):
         left = get(expression.expression_left)
         right = get(expression.expression_right)
-        if isinstance(left, list): # tuple expression:
-            if isinstance(right, list): # unbox assigment
+        if isinstance(left, list):  # tuple expression:
+            if isinstance(right, list):  # unbox assigment
                 assert len(left) == len(right)
-                for idx in range(len(left)):
+                for idx, _ in enumerate(left):
                     if not left[idx] is None:
-                        operation = convert_assignment(left[idx], right[idx], expression.type, expression.expression_return_type)
+                        operation = convert_assignment(
+                            left[idx],
+                            right[idx],
+                            expression.type,
+                            expression.expression_return_type,
+                        )
                         operation.set_expression(expression)
                         self._result.append(operation)
                 set_val(expression, None)
             else:
                 assert isinstance(right, TupleVariable)
-                for idx in range(len(left)):
+                for idx, _ in enumerate(left):
                     if not left[idx] is None:
-                        operation = Unpack(left[idx], right, idx)
+                        index = idx
+                        # The following test is probably always true?
+                        if (
+                            isinstance(left[idx], LocalVariableInitFromTuple)
+                            and left[idx].tuple_index is not None
+                        ):
+                            index = left[idx].tuple_index
+                        operation = Unpack(left[idx], right, index)
                         operation.set_expression(expression)
                         self._result.append(operation)
                 set_val(expression, None)
+        # Tuple with only one element. We need to convert the assignment to a Unpack
+        # Ex:
+        # (uint a,,) = g()
+        elif (
+            isinstance(left, LocalVariableInitFromTuple)
+            and left.tuple_index is not None
+            and isinstance(right, TupleVariable)
+        ):
+            operation = Unpack(left, right, left.tuple_index)
+            operation.set_expression(expression)
+            self._result.append(operation)
+            set_val(expression, None)
         else:
             # Init of array, like
             # uint8[2] var = [1,2];
@@ -105,11 +186,13 @@ class ExpressionToSlithIR(ExpressionVisitor):
                 self._result.append(operation)
                 set_val(expression, left)
             else:
-                operation = convert_assignment(left, right, expression.type, expression.expression_return_type)
+                operation = convert_assignment(
+                    left, right, expression.type, expression.expression_return_type
+                )
                 operation.set_expression(expression)
                 self._result.append(operation)
                 # Return left to handle
-                # a = b = 1; 
+                # a = b = 1;
                 set_val(expression, left)
 
     def _post_binary_operation(self, expression):
@@ -117,12 +200,38 @@ class ExpressionToSlithIR(ExpressionVisitor):
         right = get(expression.expression_right)
         val = TemporaryVariable(self._node)
 
-        operation = Binary(val, left, right, expression.type)
-        operation.set_expression(expression)
-        self._result.append(operation)
+        if expression.type in _signed_to_unsigned:
+            new_left = TemporaryVariable(self._node)
+            conv_left = TypeConversion(new_left, left, ElementaryType("int256"))
+            conv_left.set_expression(expression)
+            self._result.append(conv_left)
+
+            if expression.type != BinaryOperationType.RIGHT_SHIFT_ARITHMETIC:
+                new_right = TemporaryVariable(self._node)
+                conv_right = TypeConversion(new_right, right, ElementaryType("int256"))
+                conv_right.set_expression(expression)
+                self._result.append(conv_right)
+            else:
+                new_right = right
+
+            new_final = TemporaryVariable(self._node)
+            operation = Binary(new_final, new_left, new_right, _signed_to_unsigned[expression.type])
+            operation.set_expression(expression)
+            self._result.append(operation)
+
+            conv_final = TypeConversion(val, new_final, ElementaryType("uint256"))
+            conv_final.set_expression(expression)
+            self._result.append(conv_final)
+        else:
+            operation = Binary(val, left, right, _binary_to_binary[expression.type])
+            operation.set_expression(expression)
+            self._result.append(operation)
+
         set_val(expression, val)
 
-    def _post_call_expression(self, expression):
+    def _post_call_expression(
+        self, expression
+    ):  # pylint: disable=too-many-branches,too-many-statements
         called = get(expression.called)
         args = [get(a) for a in expression.arguments if a]
         for arg in args:
@@ -133,7 +242,7 @@ class ExpressionToSlithIR(ExpressionVisitor):
             # internal call
 
             # If tuple
-            if expression.type_call.startswith('tuple(') and expression.type_call != 'tuple()':
+            if expression.type_call.startswith("tuple(") and expression.type_call != "tuple()":
                 val = TupleVariable(self._node)
             else:
                 val = TemporaryVariable(self._node)
@@ -142,27 +251,66 @@ class ExpressionToSlithIR(ExpressionVisitor):
             self._result.append(internal_call)
             set_val(expression, val)
         else:
-            # If tuple
-            if expression.type_call.startswith('tuple(') and expression.type_call != 'tuple()':
-                val = TupleVariable(self._node)
-            else:
+            # yul things
+            if called.name == "caller()":
                 val = TemporaryVariable(self._node)
+                var = Assignment(val, SolidityVariableComposed("msg.sender"), "uint256")
+                self._result.append(var)
+                set_val(expression, val)
+            elif called.name == "origin()":
+                val = TemporaryVariable(self._node)
+                var = Assignment(val, SolidityVariableComposed("tx.origin"), "uint256")
+                self._result.append(var)
+                set_val(expression, val)
+            elif called.name == "extcodesize(uint256)":
+                val = ReferenceVariable(self._node)
+                var = Member(args[0], Constant("codesize"), val)
+                self._result.append(var)
+                set_val(expression, val)
+            elif called.name == "selfbalance()":
+                val = TemporaryVariable(self._node)
+                var = TypeConversion(val, SolidityVariable("this"), ElementaryType("address"))
+                self._result.append(var)
 
-            message_call = TmpCall(called, len(args), val, expression.type_call)
-            message_call.set_expression(expression)
-            # Gas/value are only accessible here if the syntax {gas: , value: }
-            # Is used over .gas().value()
-            if expression.call_gas:
-                call_gas = get(expression.call_gas)
-                message_call.call_gas = call_gas
-            if expression.call_value:
-                call_value = get(expression.call_value)
-                message_call.call_value = call_value
-            self._result.append(message_call)
-            set_val(expression, val)
+                val1 = ReferenceVariable(self._node)
+                var1 = Member(val, Constant("balance"), val1)
+                self._result.append(var1)
+                set_val(expression, val1)
+            elif called.name == "address()":
+                val = TemporaryVariable(self._node)
+                var = TypeConversion(val, SolidityVariable("this"), ElementaryType("address"))
+                self._result.append(var)
+                set_val(expression, val)
+            elif called.name == "callvalue()":
+                val = TemporaryVariable(self._node)
+                var = Assignment(val, SolidityVariableComposed("msg.value"), "uint256")
+                self._result.append(var)
+                set_val(expression, val)
+            else:
+                # If tuple
+                if expression.type_call.startswith("tuple(") and expression.type_call != "tuple()":
+                    val = TupleVariable(self._node)
+                else:
+                    val = TemporaryVariable(self._node)
+
+                message_call = TmpCall(called, len(args), val, expression.type_call)
+                message_call.set_expression(expression)
+                # Gas/value are only accessible here if the syntax {gas: , value: }
+                # Is used over .gas().value()
+                if expression.call_gas:
+                    call_gas = get(expression.call_gas)
+                    message_call.call_gas = call_gas
+                if expression.call_value:
+                    call_value = get(expression.call_value)
+                    message_call.call_value = call_value
+                if expression.call_salt:
+                    call_salt = get(expression.call_salt)
+                    message_call.call_salt = call_salt
+                self._result.append(message_call)
+                set_val(expression, val)
 
     def _post_conditional_expression(self, expression):
-        raise Exception('Ternary operator are not convertible to SlithIR {}'.format(expression))
+        raise Exception("Ternary operator are not convertible to SlithIR {}".format(expression))
 
     def _post_elementary_type_name_expression(self, expression):
         set_val(expression, expression.type)
@@ -173,6 +321,14 @@ class ExpressionToSlithIR(ExpressionVisitor):
     def _post_index_access(self, expression):
         left = get(expression.expression_left)
         right = get(expression.expression_right)
+        # Left can be a type for abi.decode(var, uint[2])
+        if isinstance(left, Type):
+            # Nested type are not yet supported by abi.decode, so the assumption
+            # Is that the right variable must be a constant
+            assert isinstance(right, Constant)
+            t = ArrayType(left, right.value)
+            set_val(expression, t)
+            return
         val = ReferenceVariable(self._node)
         # access to anonymous array
         # such as [0,1][x]
@@ -211,6 +367,13 @@ class ExpressionToSlithIR(ExpressionVisitor):
         val = TemporaryVariable(self._node)
         operation = TmpNewContract(expression.contract_name, val)
         operation.set_expression(expression)
+        if expression.call_value:
+            call_value = get(expression.call_value)
+            operation.call_value = call_value
+        if expression.call_salt:
+            call_salt = get(expression.call_salt)
+            operation.call_salt = call_salt
+
         self._result.append(operation)
         set_val(expression, val)
 
@@ -238,7 +401,9 @@ class ExpressionToSlithIR(ExpressionVisitor):
         self._result.append(operation)
         set_val(expression, val)
 
-    def _post_unary_operation(self, expression):
+    def _post_unary_operation(
+        self, expression
+    ):  # pylint: disable=too-many-branches,too-many-statements
         value = get(expression.expression)
         if expression.type in [UnaryOperationType.BANG, UnaryOperationType.TILD]:
             lvalue = TemporaryVariable(self._node)
@@ -288,5 +453,4 @@ class ExpressionToSlithIR(ExpressionVisitor):
             self._result.append(operation)
             set_val(expression, lvalue)
         else:
-            raise SlithIRError('Unary operation to IR not supported {}'.format(expression))
-
+            raise SlithIRError("Unary operation to IR not supported {}".format(expression))
